/*
** Module   : Group.java
** Abstract : API to group widgets
**
** Copyright (c) 2008-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description------------------------------
** 001 GES 20080319  @37588 Created initial version to group and traverse
**                          widgets.
** 002 CA  20130323 This must be a CommonWidget too.
** 003 CA  20130927 getFirst/LastChild must return a handle instance.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Groups widgets together into a list of siblings that can be accessed
 * via the first or last entry in the list.
 */
public interface Group
extends CommonWidget
{
   /**
    * Accesses the first widget in the list of contained widgets.
    *
    * @return   The first widget or <code>null</code> if no widgets are
    *           contained.
    */
   public handle getFirstChild();

   /**
    * Accesses the last widget in the list of contained widgets.
    *
    * @return   The last widget or <code>null</code> if no widgets are
    *           contained.
    */
   public handle getLastChild();
   
   /**
    * Accesses the next widget in the list of contained widgets.
    *
    * @param    child
    *           The widget in the list for which to find the following child.
    *
    * @return   The next widget or <code>null</code> if there is no subsequent
    *           widget.
    */
   public GenericWidget getNextChild(GenericWidget child);

   /**
    * Accesses the previous widget in the list of contained widgets.
    *
    * @param    child
    *           The widget in the list for which to find the preceding child.
    *
    * @return   The previous widget or <code>null</code> if there is no
    *           preceding widget.
    */
   public GenericWidget getPrevChild(GenericWidget child);
}
