/*
** Module   : Server.java
** Abstract : An interface holding the SERVER specific method and attribute APIs.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CS  20130211 Created initial version.
** 002 CA  20130927 Added LegacyResource annotation, to determine resource type.
*/

package com.goldencode.p2j.util;

/**
 * Interface for SERVER methods and attributes
 * <p>
 * Exposes the following Attributes and methods:
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>CLIENT-CONNECTION-ID</td>
 *    <td>{@link #getClientConnectionId()}</td>
 * </tr>
 * <tr>
 *    <td>FIRST-ASYNC-REQUEST</td>
 *    <td>{@link #getFirstAsyncRequest()}</td>
 * </tr>
 * <tr>
 *    <td>HANDLE</td>
 *    <td>n/a</td>
 * </tr>
 * <tr>
 *    <td>LAST-ASYNC-REQUEST</td>
 *    <td>{@link #getLastAsyncRequest()}</td>
 * </tr>
 * <tr>
 *    <td>RESTART-ROWID</td>
 *    <td>n/a</td>
 * </tr>
 * <tr>
 *    <td>CANCEL-REQUESTS()</td>
 *    <td>{@link #cancelRequests()}</td>
 * </tr>
 * <tr>
 *    <td>CANCEL-REQUESTS-AFTER()</td>
 *    <td>{@link #cancelRequestsAfter}</td>
 * </tr>
 * </table>
 *
 */
@LegacyResource(resource = LegacyResource.SERVER)
public interface Server 
extends CommonHandleChain
{
   /**
    * This returns the id for the AppServer connection to this handle. For Web Services the return
    * value will be an empty string.
    * 
    * @return   See above.
    */
   public character getClientConnectionId();
   
   /**
    * Returns a handle to the first asynchronous requests in the AppServer or WebService list of
    * asynchronous requests.
    * 
    * @return   See above.
    */
   public handle getFirstAsyncRequest();
   
   /**
    * Returns a handle to the last asynchronous requests in the AppServer or WebService list of
    * asynchronous requests.
    * 
    * @return   See above.
    */
   public handle getLastAsyncRequest();
   
   
   /**
    * This sends a stop condition to the AppServer or Web Service.
    * <p>
    * Depending on the type of server the stop condition is sent to, it may be handled 
    * differently.
    * 
    * @return   <code>true</code> if CONNECTED() method returns <code>true</code>, 
    *           <code>false</code> otherwise.
    */
   public logical cancelRequests();
   
   /**
    * Calls the {@link #cancelRequests()} method when the specified number of seconds have passed.
    * 
    * @param    timeSec 
    *           The time in seconds after the {@link #cancelRequests()} method will be called. 4GL
    *           allows only integer or int64 values for this parameter. 
    *         
    * @return   <code>false</code> if timer cannot be set or {@link #cancelRequests()}'s result 
    *           otherwise
    */
   public logical cancelRequestsAfter(integer timeSec);
   
   /**
    * Calls the {@link #cancelRequests()} method when the specified number of seconds have passed.
    * 
    * @param    timeSec 
    *           The time in seconds after the {@link #cancelRequests()} method will be called. 4GL
    *           allows only integer or int64 values for this parameter. 
    *         
    * @return   <code>false</code> if timer cannot be set or {@link #cancelRequests()}'s result 
    *           otherwise
    */
   public logical cancelRequestsAfter(int64 timeSec);
   
   /**
    * Calls the {@link #cancelRequests()} method when the specified number of seconds have passed.
    * 
    * @param    timeSec 
    *           The time in seconds after the {@link #cancelRequests()} method will be called. 4GL
    *           allows only integer or int64 values for this parameter. 
    *         
    * @return   <code>false</code> if timer cannot be set or {@link #cancelRequests()}'s result 
    *           otherwise
    */
   public logical cancelRequestsAfter(long timeSec);
}
